# remirepo/Fedora spec file for php-zendframework-zend-crypt
#
# Copyright (c) 2015-2017 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    514cef5556bac069e36c2cbded40e529b86bb3f2
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-crypt
%global php_home     %{_datadir}/php
%global library      Crypt
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        3.2.1
Release:        4%{?dist}
Summary:        Zend Framework %{library} component

Group:          Development/Libraries
License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-mbstring
BuildRequires:  php-hash
BuildRequires:  php-openssl
BuildRequires:  php-pcre
BuildRequires:  php-spl
BuildRequires:  php-autoloader(%{gh_owner}/zend-math)             >= 2.5
BuildRequires:  php-autoloader(%{gh_owner}/zend-stdlib)           >= 2.5
BuildRequires:  php-composer(container-interop/container-interop) >= 1.0
# From composer, "require-dev": {
#        "squizlabs/php_codesniffer": "^2.3.1",
#        "phpunit/PHPUnit": "^5.6.7"
BuildRequires:  php-composer(phpunit/phpunit)                   >= 5.6.7
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "ext-mbstring": "*",
#        "zendframework/zend-math": "^3.0",
#        "zendframework/zend-stdlib": "^2.7 || ^3.0",
#        "container-interop/container-interop": "~1.0"
Requires:       php(language) >= 5.6
Requires:       php-mbstring
%if ! %{bootstrap}
Requires:       php-autoloader(%{gh_owner}/zend-math)             >= 3.0
Requires:       php-autoloader(%{gh_owner}/zend-math)             <  4
Requires:       php-autoloader(%{gh_owner}/zend-stdlib)           >= 2.7
Requires:       php-autoloader(%{gh_owner}/zend-stdlib)           <  4
Requires:       php-composer(container-interop/container-interop) >= 1.0
Requires:       php-composer(container-interop/container-interop) <  2
# From composer, "suggest": {
#        "ext-openssl": "Required for most features of Zend\\Crypt"
Requires:       php-openssl
# Autoloader
Requires:       php-composer(fedora/autoloader)
%endif
# From phpcompatinfo report for version 3.1.0
Requires:       php-hash
Requires:       php-pcre
Requires:       php-spl
%if 0%{?fedora} >= 21
Suggests:       php-pecl(scrypt)
%endif

Obsoletes:      php-ZendFramework2-%{library} < 2.5
Provides:       php-ZendFramework2-%{library} = %{version}
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
Zend\Crypt provides support of some cryptographic tools.
The available features are:
* encrypt-then-authenticate using symmetric ciphers
  (the authentication step is provided using HMAC);
* encrypt/decrypt using symmetric and public key algorithm
  (e.g. RSA algorithm);
* generate digital sign using public key algorithm (e.g. RSA algorithm);
* key exchange using the Diffie-Hellman method;
* key derivation function (e.g. using PBKDF2 algorithm);
* secure password hash (e.g. using Bcrypt algorithm);
* generate Hash values;
* generate HMAC values;

The main scope of this component is to offer an easy and secure way
to protect and authenticate sensitive data in PHP.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE

%build
: Create dependency autoloader - deprecated
cat << 'EOF' | tee autoload.php
<?php
require_once '%{php_home}/Interop/Container/autoload.php';
EOF

: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Zend/Math/autoload.php',
    '%{php_home}/Zend/Stdlib/autoload.php',
    '%{php_home}/Interop/Container/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}

install -m644 autoload.php %{buildroot}%{php_home}/Zend/%{library}-autoload.php


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
EOF

%ifarch %arm
# see https://github.com/zendframework/zend-crypt/issues/53
rm test/Key/Derivation/ScryptTest.php
%endif

ret=0
for cmd in php php56 php71 php72; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}
%{php_home}/Zend/%{library}-autoload.php


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Dec  4 2017 Remi Collet <remi@remirepo.net> - 3.2.1-3
- switch from zend-loader to fedora/autoloader

* Wed Nov  8 2017 Remi Collet <remi@remirepo.net> - 3.2.1-2
- fix erratic FTBFS from Koschei, ignore 1 failed test on arm
  https://github.com/zendframework/zend-crypt/issues/53

* Fri Aug  4 2017 Remi Collet <remi@remirepo.net> - 3.2.1-1
- Update to 3.2.1

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Dec  7 2016 Remi Collet <remi@fedoraproject.org> - 3.2.0-1
- update to 3.2.0

* Fri Aug 12 2016 Remi Collet <remi@fedoraproject.org> - 3.1.0-1
- update to 3.1.0 for ZendFramework 3
- add dependencies autoloader
- raise dependency on PHP 5.6
- raise dependency on zend-math 3.0

* Mon Feb  8 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- raise dependency on zend-math ~2.6
- raise dependency on zend-stdlib ~2.7
- drop dependency on zend-servicemanager
- add dependency on container-interop/container-interop

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 2.5.2-1
- update to 2.5.2
- raise dependency on PHP 5.5

* Wed Aug  5 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-2
- fix dependencies

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package
